@@ -10,16 +10,12 @@ from mingus.core import diatonic
 
 class OptionClass:
 	movement = "Movement"
-	blocks="Block"
 	width=400
 	height=400
 	frontend="DefaultVisualization"
 	ensemble="none"
 	no_fluidsynth=False
-	instrument="RockDrum"
-	progression="reincarnatie"
 	verbose=True
-	midifile="default.mid"
 	meter = (4,4)
 	pass
 
@@ -87,6 +83,28 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		else:
 			return midi
 
+	def get_instruments(self):
+		res = ""
+		for x in range(self.ui.instruments.count()):
+			res += str(self.ui.instruments.item(x).text()) + ","
+		if res == "":
+			return None
+		print res
+		return res[:-1]
+
+	def get_progressions(self):
+		res = ""
+		for x in range(self.ui.progressions.count()):
+			res += str(self.ui.progressions.item(x).text()) + ","
+		return res[:-1]
+
+	def get_blocks(self):
+		res = ""
+		for x in range(self.ui.blocks.count()):
+			res += str(self.ui.blocks.item(x).text()) + ","
+		return res[:-1]
+
+
 	def start_simulation(self):
 		o = OptionClass()
 		o.SF2 = str(self.ui.soundfont.text())
@@ -98,12 +116,20 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		o.wild = float(self.ui.wildness.value())
 		o.swing = self.ui.swing.checkState()
 		o.no_fluidsynth = self.ui.no_fluidsynth.checkState()
-
+		o.instrument = self.get_instruments()
+		o.progression = self.get_progressions()
+		o.blocks = self.get_blocks()
+		print o.bpm
 		project = str(self.ui.projectname.text())
+		if project == "":
+			project = "Untitled"
 		o.midifile = self.get_file_name(project)
 
-		seq = Options.get_sequencer(o)
-		seq.play()
+		try:
+			seq = Options.get_sequencer(o)
+			seq.play()
+		except Options.OptionError, err:
+			print err
 
 
 app = QtGui.QApplication(argv)
